==> lintian_2.52.0.tar.xz: lintian-2.52.0/checks/build-systems/automake.pm <==
# build-systems/automake -- lintian check script -*- perl -*-
#
# Copyright (C) 2013 Gautier Minster
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::build_systems::automake;

use strict;
use warnings;
use autodie;

use Moo;
use namespace::clean;

with 'Lintian::Check';

sub source {
    my ($self) = @_;

    my $processable = $self->processable;

    my $makefile = $processable->index('Makefile.am');

    # If there's no Makefile.am, automake probably isn't used, we're fine
    return unless defined $makefile;

    my $deprecated_configure = $processable->index('configure.in');

    if (defined $deprecated_configure) {
        $self->tag('deprecated-configure-filename');
    }

    return;
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et

==> lintian_2.55.0.tar.xz: lintian-2.55.0/checks/build-systems/automake.pm <==
# build-systems/automake -- lintian check script -*- perl -*-
#
# Copyright (C) 2013 Gautier Minster
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::build_systems::automake;

use strict;
use warnings;
use autodie;

use Moo;
use namespace::clean;

with 'Lintian::Check';

sub source {
    my ($self) = @_;

    my $processable = $self->processable;

    my $makefile = $processable->patched->lookup('Makefile.am');

    # If there's no Makefile.am, automake probably isn't used, we're fine
    return unless defined $makefile;

    my $deprecated_configure = $processable->patched->lookup('configure.in');

    if (defined $deprecated_configure) {
        $self->tag('deprecated-configure-filename');
    }

    return;
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et
